@@ -11,6 +11,7 @@ from everviz.pages import (
     objectives,
     deltaplot,
     wells_values,
+    gradientplot,
 )
 
 logger = get_logger()
@@ -27,6 +28,7 @@ def webviz_config(api):
         wells_values.page_layout(api),
         crossplot.page_layout(api),
         controls.page_layout(api),
+        gradientplot.page_layout(api),
         deltaplot.page_layout(api),
         configuration.page_layout(api),
     ]
@@ -41,7 +43,7 @@ def webviz_config(api):
 
 
 def write_webviz_config(config, file_path):
-    with open(file_path, "w") as fh:
+    with open(file_path, "w", encoding="utf-8") as fh:
         yaml.dump(config, fh, default_flow_style=False, sort_keys=False)
     logger.info("Webviz config file created: {}".format(file_path))
 
